package de.intevation.flys.artifacts.services;

import java.util.List;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import de.intevation.artifacts.CallMeta;
import de.intevation.artifacts.GlobalContext;

import de.intevation.artifacts.common.ArtifactNamespaceContext;
import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifactdatabase.DefaultService;

import de.intevation.flys.backend.SessionHolder;
import de.intevation.flys.model.River;

import de.intevation.flys.artifacts.model.RiverFactory;

import org.hibernate.Session;

/**
 * This service provides information about the supported rivers by this
 * application.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class RiverService extends DefaultService {

    /** The logger used in this service.*/
    private static Logger logger = Logger.getLogger(RiverService.class);


    /**
     * The default constructor.
     */
    public RiverService() {
    }


    public Document process(
        Document      data,
        GlobalContext globalContext,
        CallMeta      callMeta
    ) {
        logger.debug("RiverService.process");

        Document result = XMLUtils.newDocument();

        XMLUtils.ElementCreator ec = new XMLUtils.ElementCreator(
            result,
            ArtifactNamespaceContext.NAMESPACE_URI,
            ArtifactNamespaceContext.NAMESPACE_PREFIX);

        Session session = SessionHolder.acquire();
        try {
            List<River> allRivers = RiverFactory.getRivers();

            Element rivers = ec.create("rivers");

            for (River river: allRivers) {
                Element r = ec.create("river");
                ec.addAttr(r, "name", river.getName(), true);

                rivers.appendChild(r);
            }

            result.appendChild(rivers);
        }
        finally {
            session.close();
            SessionHolder.release();
        }

        return result;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
